/**
 * Copyright (c) Snowflake Inc. (2025)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

body {
  margin: 0;
}

@font-face {
  font-family: "Source Sans Pro";
  font-weight: 400;
  font-style: normal;
  src: url("./fonts/SourceSansPro-Regular.woff2") format("woff2");
}

@font-face {
  font-family: "Source Sans Pro";
  font-weight: 600;
  font-style: normal;
  src: url("./fonts/SourceSansPro-SemiBold.woff2") format("woff2");
}

@font-face {
  font-family: "Source Sans Pro";
  font-weight: 700;
  font-style: normal;
  src: url("./fonts/SourceSansPro-Bold.woff2") format("woff2");
}
